==> lxqt-panel_1.2.1.orig.tar.xz: lxqt-panel-1.2.1/plugin-statusnotifier/translations/statusnotifier_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Impostazioni di Status Notifier</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="28"/>
        <location filename="../statusnotifierconfiguration.ui" line="38"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Un applicazione che si nasconde automaticamente rimarrà visibile per questo periodo se necessita di attenzione.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="31"/>
        <source>Attention period:</source>
        <translation>Periodo di attenzione:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="41"/>
        <source> minute(s)</source>
        <translation> minuti</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="72"/>
        <source>Change visibility of items</source>
        <translation>Cambia visibilità delle applicazioni</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="85"/>
        <source>Item</source>
        <translation>Applicazione</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="90"/>
        <source>Visibility</source>
        <translation>Visibilità</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always show</source>
        <translation>Mostra sempre</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Auto-hide</source>
        <translation>Nascondi automaticamente</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always hide</source>
        <translation>Nascondi sempre</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.1.tar.xz: lxqt-panel-2.2.1/plugin-statusnotifier/translations/statusnotifier_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Impostazioni di Status Notifier</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="25"/>
        <source>Reverse the order of items</source>
        <translation>Ordine inverso per gli elementi</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="39"/>
        <location filename="../statusnotifierconfiguration.ui" line="49"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Un applicazione che si nasconde automaticamente rimarrà visibile per questo periodo se necessita di attenzione.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="42"/>
        <source>Attention period:</source>
        <translation>Periodo di attenzione:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="52"/>
        <source> minute(s)</source>
        <translation> minuti</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="83"/>
        <source>Change visibility of items</source>
        <translation>Cambia visibilità delle applicazioni</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="96"/>
        <source>Item</source>
        <translation>Applicazione</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="101"/>
        <source>Visibility</source>
        <translation>Visibilità</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always show</source>
        <translation>Mostra sempre</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Auto-hide</source>
        <translation>Nascondi automaticamente</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always hide</source>
        <translation>Nascondi sempre</translation>
    </message>
</context>
</TS>
